@@ -257,12 +257,16 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
 
     get_commits_from_orgs = function(since,
                                      until,
-                                     verbose = TRUE,
-                                     progress = verbose) {
+                                     verbose,
+                                     progress) {
       if ("org" %in% private$searching_scope) {
         rest_engine <- private$engines$rest
         commits_table <- purrr::map(private$orgs, function(org) {
           commits_table_org <- NULL
+          repos_data <- private$get_repos_data(
+            org = org,
+            verbose = verbose
+          )
           if (!private$scan_all && verbose) {
             show_message(
               host = private$host_name,
@@ -271,29 +275,24 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
               information = "Pulling commits"
             )
           }
-          repos_names <- private$get_repos_names(
-            org = org,
-            verbose = verbose
+          full_repos_encoded <- paste0(
+            utils::URLencode(org, reserved = TRUE),
+            "%2f",
+            repos_data[["paths"]]
           )
           commits_table_org <- rest_engine$get_commits_from_repos(
-            repos_names = paste0(org, "/", repos_names),
+            full_repos_names = full_repos_encoded,
             since = since,
             until = until,
-            verbose = verbose,
-            progress = progress
+            verbose = verbose
           ) |>
             rest_engine$tailor_commits_info(org = org) |>
             rest_engine$prepare_commits_table() |>
             rest_engine$get_commits_authors_handles_and_names(
-              verbose = verbose,
-              progress = progress
+              verbose = verbose
             )
           return(commits_table_org)
-        }, .progress = if (private$scan_all && progress) {
-          "[GitHost:GitLab] Pulling commits..."
-        } else {
-          FALSE
-        }) %>%
+        }, .progress = set_progress_bar(progress, private)) |>
           purrr::list_rbind()
         return(commits_table)
       }
@@ -301,8 +300,8 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
 
     get_commits_from_repos = function(since,
                                       until,
-                                      verbose  = TRUE,
-                                      progress = verbose) {
+                                      verbose,
+                                      progress) {
       if ("repo" %in% private$searching_scope) {
         rest_engine <- private$engines$rest
         graphql_engine <- private$engines$graphql
@@ -313,7 +312,7 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
         commits_table <- purrr::map(orgs, function(org) {
           commits_table_org <- NULL
           repos <- private$orgs_repos[[org]]
-          repos_names <- paste0(utils::URLencode(org, reserved = TRUE), "%2f", repos)
+          full_repos_names <- paste0(utils::URLencode(org, reserved = TRUE), "%2f", repos)
           if (!private$scan_all && verbose) {
             show_message(
               host = private$host_name,
@@ -323,40 +322,66 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
             )
           }
           commits_table_org <- rest_engine$get_commits_from_repos(
-            repos_names = repos_names,
+            full_repos_names = full_repos_names,
             since = since,
             until = until,
-            verbose = verbose,
-            progress = progress
+            verbose = verbose
           ) |>
             rest_engine$tailor_commits_info(org = org) |>
             rest_engine$prepare_commits_table() |>
             rest_engine$get_commits_authors_handles_and_names(
-              verbose = verbose,
-              progress = progress
+              verbose = verbose
             )
           return(commits_table_org)
-        }, .progress = if (private$scan_all && progress) {
-          "[GitHost:GitLab] Pulling commits..."
-        } else {
-          FALSE
-        }) %>%
+        }, .progress = set_progress_bar(progress, private)) |>
           purrr::list_rbind()
         return(commits_table)
       }
     },
 
     # Use repositories either from parameter or, if not set, pull them from API
-    get_repos_names = function(org, verbose) {
-      graphql_engine <- private$engines$graphql
-      owner_type <- attr(org, "type") %||% "organization"
-      repos_names <- graphql_engine$get_repos_from_org(
-        org = utils::URLdecode(org),
-        owner_type = owner_type,
-        verbose = verbose
-      ) |>
-        purrr::map_vec(~ .$node$repo_path)
-      return(repos_names)
+    get_repos_data = function(org, repos = NULL, verbose) {
+      if (!is.null(repos)) {
+        repos_names <- repos
+      } else {
+        cached_repos <- private$get_cached_repos(org)
+        if (is.null(cached_repos)) {
+          if (verbose) cli::cli_alert("Pulling repositories data...")
+          graphql_engine <- private$engines$graphql
+          owner_type <- attr(org, "type") %||% "organization"
+          repos_from_org <- graphql_engine$get_repos_from_org(
+            org = utils::URLdecode(org),
+            owner_type = owner_type,
+            verbose = verbose
+          )
+          if (inherits(repos_from_org, "graphql_error")) {
+            if (verbose) {
+              cli::cli_alert_info("Switching to REST API...")
+            }
+            rest_engine <- private$engines$rest
+            repos_from_org <- rest_engine$get_repos_from_org(
+              org = utils::URLencode(org, reserved = TRUE),
+              output = "raw",
+              verbose = verbose
+            )
+          } else {
+            repos_from_org <- purrr::map(repos_from_org, function(repos_data) {
+              repos_data$path <- repos_data$node$repo_path
+              repos_data
+            })
+          }
+          private$set_cached_repos(repos_from_org, org, verbose)
+        } else {
+          if (verbose) cli::cli_alert("Using cached repositories data...")
+          repos_from_org <- cached_repos
+        }
+        repos_names <- repos_from_org |>
+          purrr::map_vec(~ .$path)
+      }
+      repos_data <- list(
+        "paths" = repos_names
+      )
+      return(repos_data)
     },
 
     are_non_text_files = function(file_path, host_files_structure) {
@@ -369,6 +394,56 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
       }
     },
 
+    get_files_structure_from_repos = function(pattern,
+                                              depth,
+                                              verbose  = TRUE,
+                                              progress = TRUE) {
+      if ("repo" %in% private$searching_scope) {
+        graphql_engine <- private$engines$graphql
+        orgs <- graphql_engine$set_owner_type(
+          owners = names(private$orgs_repos),
+          verbose = verbose
+        )
+        files_structure_list <- purrr::map(orgs, function(org) {
+          if (verbose) {
+            user_info <- if (!is.null(pattern)) {
+              glue::glue(
+                "Pulling repos \U1F333 [files matching pattern: '{paste0(pattern, collapse = '|')}']"
+              )
+            } else {
+              glue::glue("Pulling repos \U1F333")
+            }
+            show_message(
+              host = private$host_name,
+              engine = "graphql",
+              scope = set_repo_scope(org, private),
+              information = user_info
+            )
+          }
+          owner_type <- attr(org, "type") %||% "organization"
+          graphql_engine$get_files_structure_from_org(
+            org = org,
+            owner_type = owner_type,
+            repos_data = list("paths" = private$orgs_repos[[org]]),
+            pattern = pattern,
+            depth = depth,
+            verbose = verbose
+          )
+        }, .progress = set_progress_bar(progress, private))
+        names(files_structure_list) <- orgs
+        files_structure_list <- files_structure_list %>%
+          purrr::discard(~ length(.) == 0)
+        if (length(files_structure_list) == 0 && verbose) {
+          cli::cli_alert_warning(
+            cli::col_yellow(
+              "For {private$host_name} no files structure found."
+            )
+          )
+        }
+        return(files_structure_list)
+      }
+    },
+
     # Pull files content from organizations
     get_files_content_from_repos = function(file_path,
                                             verbose = TRUE,
@@ -392,15 +467,14 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
           graphql_engine$get_files_from_org_per_repo(
             org = org,
             owner_type = owner_type,
-            repos = private$orgs_repos[[org]],
+            repos_data = list("paths" = private$orgs_repos[[org]]),
             file_paths = file_path,
-            verbose = verbose,
-            progress = progress
+            verbose = verbose
           ) |>
             graphql_engine$prepare_files_table(
               org = org
             )
-        }) |>
+        }, .progress = set_progress_bar(progress, private)) |>
           purrr::list_rbind() |>
           private$add_repo_api_url()
         return(files_table)
@@ -429,15 +503,14 @@ GitHostGitLab <- R6::R6Class("GitHostGitLab",
         graphql_engine$get_files_from_org_per_repo(
           org = org,
           owner_type = owner_type,
-          repos = repos,
+          repos_data = list("paths" = repos),
           host_files_structure = files_structure,
-          verbose = verbose,
-          progress = progress
+          verbose = verbose
         ) |>
           graphql_engine$prepare_files_table(
             org = org
           )
-      }) |>
+      }, .progress = set_progress_bar(progress, private)) |>
         purrr::list_rbind() |>
         private$add_repo_api_url()
       return(files_table)
