@@ -56,6 +56,23 @@ test_that("get_commits works properly", {
   test_mocker$cache(commits_table)
 })
 
+test_that("get_commits prints warning when commits table is empty", {
+  mockery::stub(
+    test_gitstats$get_commits,
+    "private$get_commits_from_hosts",
+    data.frame()
+  )
+  expect_snapshot(
+    commits_table <- test_gitstats$get_commits(
+      since = "2023-06-15",
+      until = "2023-06-30",
+      cache = FALSE,
+      verbose = TRUE
+    )
+  )
+  expect_equal(nrow(commits_table), 0)
+})
+
 test_that("get_commits() works", {
   mockery::stub(
     get_commits,
