@@ -62,7 +62,9 @@ test_that("get_files_structure_from_repo() pulls files structure from repo", {
   }
   gl_files_structure <- test_graphql_gitlab_priv$get_files_structure_from_repo(
     org = "mbtests",
-    repo = "graphql_tests"
+    repo = "graphql_tests",
+    depth = 1L,
+    pattern = NULL
   )
   expect_type(
     gl_files_structure,
@@ -128,26 +130,22 @@ if (integration_tests_skipped) {
 
 test_that("GitLab GraphQL Engine pulls files structure from repositories", {
   if (integration_tests_skipped) {
-    gl_repos_data <- list(
-      "repositories" = gl_repos
-    )
-    mockery::stub(
-      test_graphql_gitlab$get_files_structure_from_org,
-      "private$get_repos_data",
-      gl_repos_data
-    )
     mockery::stub(
       test_graphql_gitlab$get_files_structure_from_org,
       "private$get_files_structure_from_repo",
       test_mocker$use("gl_files_structure")
     )
   }
+  gl_repos_data <- list(
+    "paths" = gl_repos
+  )
   gl_files_structure <- test_graphql_gitlab$get_files_structure_from_org(
     org = "mbtests",
-    repos = gl_repos,
+    repos_data = gl_repos_data,
     owner_type = "organization",
-    verbose  = FALSE,
-    progress = FALSE
+    pattern = NULL,
+    depth = 1L,
+    verbose  = FALSE
   )
   purrr::walk(gl_files_structure, ~ expect_true(length(.) > 0))
   expect_equal(
@@ -159,28 +157,22 @@ test_that("GitLab GraphQL Engine pulls files structure from repositories", {
 
 test_that("GitLab GraphQL Engine pulls files structure from repositories when repos are not set", {
   if (integration_tests_skipped) {
-    gl_repos_data <- list(
-      "repositories" = gl_repos
-    )
-    mockery::stub(
-      test_graphql_gitlab$get_files_structure_from_org,
-      "private$get_repos_data",
-      gl_repos_data
-    )
     mockery::stub(
       test_graphql_gitlab$get_files_structure_from_org,
       "private$get_files_structure_from_repo",
       test_mocker$use("gl_md_files_structure")
     )
   }
+  gl_repos_data <- list(
+    "paths" = gl_repos
+  )
   gl_files_structure_shallow <- test_graphql_gitlab$get_files_structure_from_org(
     org = "mbtests",
-    repos =  NULL,
+    repos_data = gl_repos_data,
     pattern = "\\.md",
     owner_type = "organization",
     depth = 1L,
-    verbose = FALSE,
-    progress = FALSE
+    verbose = FALSE
   )
   purrr::walk(gl_files_structure_shallow, ~ expect_true(length(.) > 0))
   expect_equal(
@@ -191,27 +183,25 @@ test_that("GitLab GraphQL Engine pulls files structure from repositories when re
   test_mocker$cache(gl_files_structure_shallow)
 })
 
-gl_group <- if (integration_tests_skipped) {
-  "test_group"
-} else {
-  "mbtests"
-}
+gl_group <- "mbtests"
 
 test_that("get_files_structure_from_orgs pulls files structure for repositories in orgs", {
-  mockery::stub(
-    gitlab_testhost_priv$get_files_structure_from_orgs,
-    "graphql_engine$get_files_structure_from_org",
-    test_mocker$use("gl_files_structure_shallow")
-  )
+  if (integration_tests_skipped) {
+    mockery::stub(
+      gitlab_testhost_priv$get_files_structure_from_orgs,
+      "graphql_engine$get_files_structure_from_org",
+      test_mocker$use("gl_files_structure_shallow")
+    )
+  }
   gl_files_structure_from_orgs <- gitlab_testhost_priv$get_files_structure_from_orgs(
-    pattern  = "\\.md",
-    depth    = 1L,
-    verbose  = FALSE,
+    pattern = "\\.md",
+    depth = 1L,
+    verbose = FALSE,
     progress = FALSE
   )
   expect_equal(
     names(gl_files_structure_from_orgs),
-    c(gl_group)
+    gl_group
   )
   purrr::walk(gl_files_structure_from_orgs[[1]], function(repo_files) {
     expect_true(all(grepl("\\.md", repo_files)))
@@ -219,6 +209,61 @@ test_that("get_files_structure_from_orgs pulls files structure for repositories
   test_mocker$cache(gl_files_structure_from_orgs)
 })
 
+test_that("get_files_structure_from_repos pulls files structure for repositories", {
+  mockery::stub(
+    gitlab_testhost_priv$get_files_structure_from_repos,
+    "graphql_engine$get_files_structure_from_org",
+    test_mocker$use("gl_files_structure_shallow")
+  )
+  test_org <- "mbtests"
+  attr(test_org, "type") <- "organization"
+  mockery::stub(
+    gitlab_testhost_priv$get_files_structure_from_repos,
+    "graphql_engine$set_owner_type",
+    test_org
+  )
+  gitlab_testhost_priv$searching_scope <- "repo"
+  gl_files_structure_from_repos <- gitlab_testhost_priv$get_files_structure_from_repos(
+    pattern = "\\.md",
+    depth = 1L,
+    verbose = FALSE,
+    progress = FALSE
+  )
+  expect_equal(
+    names(gl_files_structure_from_repos),
+    gl_group
+  )
+  purrr::walk(gl_files_structure_from_repos[[1]], function(repo_files) {
+    expect_true(all(grepl("\\.md", repo_files)))
+  })
+  gitlab_testhost_priv$searching_scope <- "org"
+})
+
+test_that("get_files_structure_from_repos prints message", {
+  mockery::stub(
+    gitlab_testhost_priv$get_files_structure_from_repos,
+    "graphql_engine$get_files_structure_from_org",
+    test_mocker$use("gl_files_structure_shallow")
+  )
+  test_org <- "test_group"
+  attr(test_org, "type") <- "organization"
+  mockery::stub(
+    gitlab_testhost_priv$get_files_structure_from_repos,
+    "graphql_engine$set_owner_type",
+    test_org
+  )
+  gitlab_testhost_priv$searching_scope <- "repo"
+  expect_snapshot(
+    gl_files_structure_from_repos <- gitlab_testhost_priv$get_files_structure_from_repos(
+      pattern = "\\.md",
+      depth = 1L,
+      verbose = TRUE,
+      progress = FALSE
+    )
+  )
+  gitlab_testhost_priv$searching_scope <- "org"
+})
+
 test_that("get_path_from_files_structure gets file path from files structure", {
   test_graphql_gitlab <- EngineGraphQLGitLab$new(
     gql_api_url = "https://gitlab.com/api/v4/graphql",
@@ -240,9 +285,9 @@ test_that("get_files_structure pulls files structure for repositories in orgs",
     test_mocker$use("gl_files_structure_from_orgs")
   )
   gl_files_structure_from_orgs <- gitlab_testhost$get_files_structure(
-    pattern  = "\\.md",
-    depth    = 1L,
-    verbose  = FALSE,
+    pattern = "\\.md",
+    depth = 1L,
+    verbose = FALSE,
     progress = FALSE
   )
   expect_equal(
