@@ -35,8 +35,7 @@ test_that("get_repositories_with_files works", {
     def_branches = c("test_branch_1", "test_branch_2", "test_branch_3", "test_branch_4", "test_branch_5"),
     org = "test_org",
     file_paths = "test_files.txt",
-    host_files_structure = NULL,
-    progress = FALSE
+    host_files_structure = NULL
   )
   expect_type(gh_repositories_with_files, "list")
   test_mocker$cache(gh_repositories_with_files)
@@ -59,8 +58,7 @@ test_that("GitHub GraphQL Engine pulls files from organization", {
     repos = NULL,
     file_paths = "test_files.txt",
     host_files_structure = NULL,
-    verbose = FALSE,
-    progress = FALSE
+    verbose = FALSE
   )
   expect_github_files_response(github_files_response)
   test_mocker$cache(github_files_response)
@@ -93,23 +91,6 @@ test_that("get_files_content_from_orgs for GitHub works", {
   test_mocker$cache(gh_files_from_orgs)
 })
 
-test_that("get_files_content makes use of files_structure", {
-  mockery::stub(
-    github_testhost_priv$get_files_content_from_files_structure,
-    "private$add_repo_api_url",
-    test_mocker$use("gh_files_from_orgs")
-  )
-  expect_snapshot(
-    files_content <- github_testhost_priv$get_files_content_from_files_structure(
-      files_structure = test_mocker$use("gh_files_structure_from_orgs")
-    )
-  )
-  expect_files_table(
-    files_content,
-    with_cols = "api_url"
-  )
-})
-
 test_that("get_files_content_from_repos for GitHub works", {
   test_org <- "test_org"
   attr(test_org, "type") <- "organization"
@@ -118,6 +99,11 @@ test_that("get_files_content_from_repos for GitHub works", {
     "graphql_engine$set_owner_type",
     test_org
   )
+  mockery::stub(
+    github_testhost_priv$get_files_content_from_repos,
+    "private$get_repos_data",
+    test_mocker$use("gh_repos_data")
+  )
   mockery::stub(
     github_testhost_priv$get_files_content_from_repos,
     "graphql_engine$prepare_files_table",
@@ -135,6 +121,30 @@ test_that("get_files_content_from_repos for GitHub works", {
   test_mocker$cache(gh_files_from_repos)
 })
 
+test_that("get_files_content makes use of files_structure", {
+  mockery::stub(
+    github_testhost_priv$get_files_content_from_files_structure,
+    "private$get_repos_data",
+    test_mocker$use("gh_repos_data")
+  )
+  mockery::stub(
+    github_testhost_priv$get_files_content_from_files_structure,
+    "graphql_engine$prepare_files_table",
+    test_mocker$use("gh_files_table")
+  )
+  expect_snapshot(
+    files_content <- github_testhost_priv$get_files_content_from_files_structure(
+      files_structure = test_mocker$use("gh_files_structure_from_orgs"),
+      verbose = TRUE,
+      progress = FALSE
+    )
+  )
+  expect_files_table(
+    files_content,
+    with_cols = "api_url"
+  )
+})
+
 test_that("`get_files_content()` pulls files in the table format", {
   github_testhost <- create_github_testhost(orgs = "test_org")
   mockery::stub(
