@@ -34,22 +34,6 @@ test_that("`prepare_releases_table()` prepares releases table", {
   test_mocker$cache(releases_table)
 })
 
-test_that("`get_repos_names` works", {
-  mockery::stub(
-    gitlab_testhost_priv$get_repos_names,
-    "graphql_engine$get_repos_from_org",
-    test_mocker$use("gl_repos_from_org")
-  )
-  gitlab_testhost_priv$orgs_repos <- list("test_org" = "TestRepo")
-  gitlab_testhost_priv$searching_scope <- "org"
-  repos_names <- gitlab_testhost_priv$get_repos_names(
-    org = "test_org"
-  )
-  expect_type(repos_names, "character")
-  expect_gt(length(repos_names), 0)
-  test_mocker$cache(repos_names)
-})
-
 test_that("`get_release_logs_from_orgs()` works", {
   mockery::stub(
     gitlab_testhost_priv$get_release_logs_from_orgs,
@@ -58,14 +42,14 @@ test_that("`get_release_logs_from_orgs()` works", {
   )
   mockery::stub(
     gitlab_testhost_priv$get_release_logs_from_orgs,
-    "private$get_repos_names",
-    test_mocker$use("repos_names")
+    "private$get_repos_data",
+    test_mocker$use("gl_repos_data")
   )
   gitlab_testhost_priv$searching_scope <- "org"
   releases_from_orgs <- gitlab_testhost_priv$get_release_logs_from_orgs(
-    since    = "2023-05-01",
-    until    = "2023-09-30",
-    verbose  = FALSE,
+    since = "2023-05-01",
+    until = "2023-09-30",
+    verbose = FALSE,
     progress = FALSE
   )
   expect_releases_table(releases_from_orgs)
@@ -80,15 +64,15 @@ test_that("`get_release_logs_from_orgs()` prints proper message", {
   )
   mockery::stub(
     gitlab_testhost_priv$get_release_logs_from_orgs,
-    "private$get_repos_names",
-    test_mocker$use("repos_names")
+    "private$get_repos_data",
+    test_mocker$use("gl_repos_data")
   )
   gitlab_testhost_priv$searching_scope <- "org"
   expect_snapshot(
     releases_from_orgs <- gitlab_testhost_priv$get_release_logs_from_orgs(
-      since    = "2023-05-01",
-      until    = "2023-09-30",
-      verbose  = TRUE,
+      since = "2023-05-01",
+      until = "2023-09-30",
+      verbose = TRUE,
       progress = FALSE
     )
   )
@@ -107,9 +91,9 @@ test_that("`get_release_logs_from_repos()` works", {
   gitlab_testhost_priv$orgs_repos <- list("test_org" = "TestRepo")
   expect_snapshot(
     releases_from_repos <- gitlab_testhost_priv$get_release_logs_from_repos(
-      since    = "2023-05-01",
-      until    = "2023-09-30",
-      verbose  = TRUE,
+      since = "2023-05-01",
+      until = "2023-09-30",
+      verbose = TRUE,
       progress = FALSE
     )
   )
@@ -127,9 +111,9 @@ test_that("`get_release_logs_from_repos()` works", {
   )
   gitlab_testhost_priv$orgs_repos <- list("test_org" = "TestRepo")
   releases_from_repos <- gitlab_testhost_priv$get_release_logs_from_repos(
-    since    = "2023-05-01",
-    until    = "2023-09-30",
-    verbose  = FALSE,
+    since = "2023-05-01",
+    until = "2023-09-30",
+    verbose = FALSE,
     progress = FALSE
   )
   expect_releases_table(releases_from_repos)
@@ -148,9 +132,9 @@ test_that("`get_release_logs()` pulls release logs in the table format", {
     test_mocker$use("releases_from_orgs")
   )
   releases_table <- gitlab_testhost$get_release_logs(
-    since    = "2023-08-01",
-    until    = "2024-06-30",
-    verbose  = FALSE,
+    since = "2023-08-01",
+    until = "2024-06-30",
+    verbose = FALSE,
     progress = FALSE
   )
   expect_releases_table(releases_table)
